## v1.7.0 (2022-10-12)

### Feat

- **logger**: add support for stack trace (#13)

## v1.6.0 (2022-09-30)

### Feat

- **logger**: aded support to move additional fields to metadata (#9)

## v1.5.0 (2022-09-29)

### Feat

- **logger**: added manual trigger and restrict access (#8)
- **logger**: added line number to logs (#7)

## v1.4.0 (2022-09-27)

### Feat

- **logger**: added support for additional fields in logger init (#6)

## v1.3.0 (2022-09-26)

### Feat

- **logger**: Added support to provide multiple handlers during init (#5)

## v1.2.0 (2022-09-26)

### Feat

- **logger**: renamed serviceName field to service (#4)

## v1.1.0 (2022-09-23)

### Feat

- **logger**: added support to provide service name during logger init (#3)

## v1.0.1 (2022-09-21)

### Fix

- add few spaces to test out auto release

## v1.0.0 (2022-09-21)

### Feat

- **logger**: Add initial version of logger with boilerplate (#1)
